The MPL Reference Manual: Intrinsic Metafunctions

Front Page / Sequences / Intrinsic Metafunctions

# Intrinsic Metafunctions

The metafunctions that form the essential interface of sequence classes documented in the corresponding sequence concepts are known as intrinsic sequence operations. They differ from generic sequence algorithms in that, in general, they need to be implemented from scratch for each new sequence class [1].

It's worth noting that STL counterparts of these metafunctions are usually implemented as member functions.

[1] | In practice, many of intrinsic metafunctions offer a default implementation that will work in majority of cases, given that you've implemented the core functionality they rely on (such as begin / end).